 /*
class BankJdbcApp
MSc IT DBIS Application
Monica Farrow / Calum Hutchison

This is the main interface for the application.
A connection is made to the database 
and the main switchboard is set up and shown  
 
*/

import java.sql.*;
import java.awt.*;
import java.io.*;
import java.util.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;

public class DBISJdbcApp extends JFrame 
						implements ActionListener
{
	//url details
	final String urlstart = "jdbc:oracle:thin:";
	final String urlend = "@crooked.dcs.gla.ac.uk:1521:masters";
	String urluserpass;
	
	//database connection	
	Connection db;
	
	//swing components
	JScrollPane scroll;
	JTable tab;
	JButton parQuery,ownSQL;
	JComboBox tableList, descList;
	JLabel tableHeading;
	QueryTable  quTable;
	JTextArea feedback;
	
	//first part of SQL to list complete table
	String selectAll = "Select * from ";
	
	//instructions for switchboard
	String tableListLabel = "Choose a name to see the contents of that table "
									+ " or view ";
	String descListLabel = "Choose a description to see the details ";
	String ownSQLLabel = "Enter your own SQL query ";
	String paramQLabel = "Run a predefined parameterised query ";
	
		
	//connects to database and sets up GUI 
	public DBISJdbcApp() 
	{
		//initialises frame
		super();
		this.setTitle(DBInfo.dbName + " SwitchBoard");        
		this.setSize(750, 650);
		this.addWindowListener(new WindowCloser());
		
		//connects to database
  		connectToDatabase();
  		//set prepared statements
  		try
		{
  			DBInfo.setAllPrepStatements(db);
		}
		catch (SQLException e)
		{
			System.out.println("Setting Prepared Statements " + e.getMessage());
		}
	
		
		//MAKE  TOP PANEL
		JPanel topPanel = new JPanel();			
		topPanel.setLayout(new GridLayout(5,3));
		
  		// Add each table to the table combo box 
		tableList = new JComboBox();
	    tableList.setEditable(true);
		for (int i = 0; i < DBInfo.tables.length; i++)
		{
			tableList.addItem(DBInfo.tables[i]);
		}
		tableList.addActionListener(this);
		topPanel.add(new JLabel(tableListLabel, SwingConstants.RIGHT));
		topPanel.add(tableList);
		
		
		// Add each query to the query combo box
		descList = new JComboBox();
	    descList.setEditable(true);

		for (int i = 0; i < DBInfo.descQueries.length; i++)
		{
			descList.addItem(DBInfo.descQueries[i].getDesc());
		}
	   	descList.addActionListener(this); 
	   	topPanel.add(new JLabel(descListLabel, SwingConstants.RIGHT));
	   	topPanel.add(descList);
		
		 
		//add Parameterised Query button
		parQuery = new JButton("Parameterised Query");
		parQuery.addActionListener(this);
		topPanel.add(new JLabel(paramQLabel, SwingConstants.RIGHT));
		topPanel.add(parQuery);
		
		//add own SQL Query button
		ownSQL = new JButton("New SQL Query");
		ownSQL.addActionListener(this);
		topPanel.add(new JLabel(ownSQLLabel, SwingConstants.RIGHT));
		topPanel.add(ownSQL);
		
		//add table heading
		tableHeading = new JLabel("");	
		tableHeading.setForeground(Color.black);
		tableHeading.setFont(new Font("SansSerif", Font.BOLD, 16));	
		topPanel.add(tableHeading);
		
		//addTextArea
		JPanel sPanel = new JPanel();
		feedback = new JTextArea(5,60);
		JScrollPane jsp = new JScrollPane(feedback);
		sPanel.add(jsp);
		

		//CREATE TABLE IN SCROLLPANE		
		//The table will contain the query results
		quTable = new QueryTable();
		tab = new JTable(quTable);
		scroll = new JScrollPane(tab);

		
		//ADD PANELS TO CONTENT PANE
		getContentPane().add(topPanel, BorderLayout.NORTH);
		getContentPane().add(sPanel, BorderLayout.SOUTH);
		getContentPane().add(scroll, BorderLayout.CENTER);
		
    }
    
    
    /////////////////////////////////////////////////////////////////
    //METHOD actionPerformed
    //Handles all actions from GUI
    //If table listing required, execute 'Select All'
    //	(table is displayed in scrollpane)
    //Else If parameterised query or own SQL query is required
    //	open specialised frame
	public void actionPerformed(ActionEvent evt)  
	{
		Object source = evt.getSource();
		
		//If table listing required, execute 'Select All'
		// (table is displayed in scrollpane)
		if (source == tableList)
		{
			String sql ="";
			try
			{
				String table = (String) tableList.getSelectedItem();
				Statement stmt = db.createStatement();
				sql = selectAll + DBInfo.owner + '.' + table;
				ResultSet rs= stmt.executeQuery(sql);
				quTable.formatTable(rs);
				tableHeading.setText(table);
				feedback.setText("");
			}
			catch (SQLException e)
			{
				feedback.setText(e + sql);
			}
		}
		
		//If description listing required, find table/view name, 
		// then execute 'Select All'
		// (table displayed in scrollpane)
		else if (source == descList)
		{
			String sql = "";
			try
			{
				String queryDesc = (String)descList.getSelectedItem();
				DescQuery dq = DBInfo.findDescQuery(queryDesc);
				sql = selectAll + DBInfo.owner + '.' + dq.getName();
				Statement stmt = db.createStatement();
				ResultSet rs= stmt.executeQuery(sql);
				quTable.formatTable(rs);
				tableHeading.setText(dq.getDesc());	
				feedback.setText("");
			}
			catch (SQLException e)
			{
				feedback.setText(e + sql);
			}		
		}
		

		// If parameterised query required, open that frame
		else if (source == parQuery)
		{
			feedback.setText("");
			ParamQueryFrame query = new ParamQueryFrame(db);
			query.setVisible(true);
		}
		// if own SQL Query required, open SQL frame
		else if (source == ownSQL)
		{
			feedback.setText("");
			SQLQuery sq = new SQLQuery(db);
			sq.setVisible(true);
		}


	}
	
	
	/////////////////////////////////////////////////////////////////
	// Obtain user name and password	 
	// Connect to database 	
	void connectToDatabase()
	{
		// Obtain user name and password	
		UserPassDialog upd = new UserPassDialog(this);
		upd.setLocation(200,200);
		LogOn logonInfo = upd.showDialog();				
				
		String url = urlstart + logonInfo.getUNamePWord() + urlend; 
		String odbc = "jdbc:odbc:"+logonInfo.getOdbcName();
		// Connect to database 
		try 
		{
			if (logonInfo.isOracleType())
			{
				// Get a Connection to the database
				new oracle.jdbc.driver.OracleDriver();	
				System.out.println(url);
	  			db = DriverManager.getConnection(url);	
			}
			else
			{

				Class.forName("sun.jdbc.odbc.JdbcOdbcDriver");		
				db = DriverManager.getConnection(odbc);
            db.getCatalog();
			}
			
		}
		catch(Exception e) 
		{
  			System.out.println("Could not initialize the database." 
											+ e.getMessage());
			e.printStackTrace();
  			System.exit(0);
		}

   	}
   	


   	/////////////////////////////////////////////////////////////////
   	public static void main(String args[]) 
  	{		
  		DBISJdbcApp f = new DBISJdbcApp();
		f.setVisible(true);	
	}
	  
	  

	/////////////////////////////////////////////////////////////////  	
	// Inner class for window closing 
	// Close DB conection then exit
	class WindowCloser extends WindowAdapter
	{
		public void windowClosing(WindowEvent event)
		{	
  			try 
  			{
				if (db != null) 		
				{  	
					db.close();
	    		}
				System.exit(0);
	  		}
  	
  			catch(Exception e) 
  			{
    			System.out.println("Could not close the current connection.");
    			e.printStackTrace();
	  		}
		
		}
	}
	
}