
/*
MSc IT DBIS Application / Servlet
Monica Farrow 

Contains all details about the database :
	Database Name
	OwnerName
	Table / View names
	Descriptions and corresponding table/view names
	Declarations for each parameterised query
Methods;
	For descriptions, returns DescQuery object, given the description
	For parameterised queries
		Sets all prepared statements
		Returns number of queries
		Returns OneParamQuery at location
*/

import java.sql.*;
import java.io.*;

class DBInfo
{
////////////////////////////////////////////////////////////////////////////
//Just change from here to the next dividing line
	
	public static String owner = "M09_rich";	//username
	public static String dbName = "Bank";		//database subject
	public static String tables [] =
		{							//table / view  names
			"ACCOUNT", 
			"CUSTOMER", 
			"OWNER",
			"EMPLOYEE",
			"BRANCH"
		 };
	
	//Table/ View names and Description  	 
	public static  DescQuery descQueries [] = 
		{	
		    new DescQuery ("CURRENTACCOUNTS", "Details of all current accounts"),
		    new DescQuery ("FEMCUST", "List of female customers")
		};
		
	//PARAMETERISED QUERIES	
	/*
	Have a set of Strings for each query:
	q?		: parameterised query with ? in place of parameter
	t?		: query description for menu and window title
	l?		: label for combo box of parameterised column values
	p?		: query to get all possible parameters 
	*/
	
	static String q0   = "Select AccountNo, Type, Balance, DateOpened " 
  	          		   	+ "From " + owner + ".account where inBranch = ? "
	  							+ "Order by Type, AccountNo";
  	static String t0   = "Accounts at a particular branch";
  	static String l0   = "Choose  Branch number: ";
	static String p0	 = "Select distinct branchNo from " + owner + ".Branch "
		   					+ " order by branchNo";  
  	
  	static String q1   = "Select AccountNo, Type, Balance, DateOpened, " +
								" InBranch, CustID "
  		        				+ "From " + owner + ".Account, " + owner + ".Owner "
	        					+ "Where AccountNo = AccNo "
	        					+ "And AccountNo = ?";
  	static String t1   = "Details of a particular account";
  	static String l1   = "Choose Account number: ";
	static String p1	 = "Select distinct AccountNo from " + owner + ".Account "
		   					+ " order by AccountNo";  
  	

 	static String q2   = "Select StaffNo, Forename, Surname, Supervisor "
  						+ "From " + owner + ".Employee "
  						+ "Where EmpBranch = ?"
 						+ " Order by Surname, Forename";
  	static String t2   = "Staff members working at a particular branch";
  	static String l2   = "Choose  Branch number: ";
	static String p2	 = "Select distinct branchNo from " + owner + ".Branch "
		   					+ " order by branchNo"; 
  	
 	static String q3   = "Select s.StaffNo, s.Forename, s.Surname from "
  		 				 		+ owner + ".Employee s, " + owner + ".Employee e "
  		 						+ "where e.Supervisor = s.StaffNo "
  		 						+ "and e.StaffNo = ?";
 	static String t3   = "Details of a staff members supervisor";
 	static String l3   = "Choose  Staff number: ";
	static String p3	 = "Select distinct StaffNo from " + owner + ".Employee "
		   					+ " order by StaffNo"; 
  	
 	static String q4   = "Select AccountNo, Type, Balance, DateOpened,InBranch "
  								+ "From " + owner + ".Account , " + owner + ".Owner "
  								+ "Where AccNo = AccountNo "
  								+ "and CustID = ?";
	static String t4   = "Accounts belonging to a particular customer.";
	static String l4   = "Choose Customer ID:  ";
	static String p4	 = "Select distinct ID from " + owner + ".Customer "
		   					+ " order by ID"; 
  	
	static OneParamQuery params [] =
		{	
			new OneParamQuery(q0, t0,l0, p0),
			new OneParamQuery(q1, t1,l1, p1),
			new OneParamQuery(q2, t2,l2, p2),
			new OneParamQuery(q3, t3,l3, p3),	
			new OneParamQuery(q4, t4,l4, p4)	
		};	

/////////////////////////////////////////////////////////////////////////////////

	public static void setAllPrepStatements(Connection conn) throws SQLException
	{
		for (int i = 0; i<params.length; i++)
		{
			params[i].setPrepStatement(conn);
		}	
	}

	//returns number of Queries
	public  static int getNumQueries()
	{	if (params!= null)
			return params.length; 
		else return 0;
	}
	
	//returns the parameter at a specific location
	public static OneParamQuery getParamAt(int i)
	{ 	return params[i];  }
	
	//Find paramquery object from list, using query title 
	public static OneParamQuery findQuery(String queryTitle)  
	{
		OneParamQuery q = params[0];
		for (int i = 0; i < params.length; i++)
		{
			if (queryTitle.equals(params[i].getTitle()))
			{
				q = params[i];
			}
		}
		return q;	
	}
	
	//Find desc query object from list, using query description
	public static DescQuery findDescQuery(String queryTitle)  
	{
		DescQuery q = descQueries[0];
		for (int i = 0; i < descQueries.length; i++)
		{
			if (queryTitle.equals(descQueries[i].getDesc()))
			{
				q = descQueries[i];
			}
		}
		return q;	
	}	
}