 /*
class ParamQueryFrame
MSc IT DBIS Application
Monica Farrow / Calum Hutchison
  
This frame is used parameterised queries
Two combo boxes show possible queries and parameter values
When a query is selected,
   an SQL query is run to find the possible parameter values
   these are displayed in the second combo box
When a parameter value is chosen,
   the query is executed
    the resulting data is displayed
  */

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.table.*;
import java.sql.*;

public class ParamQueryFrame extends JFrame
implements ActionListener {
   JTextField queryField;
   QueryTable quTable;
   JComboBox pQueries, param;
   JLabel paramL;
   JScrollPane scrollPane;
   JTextArea feedback;
   Connection db;
   OneParamQuery parQuery;
   
   
   //Constructor with database connection c
   public ParamQueryFrame(Connection conn) 
   {
      //initialise frame
      super("Parameterised queries");
      this.setSize(750,400);
      
      db = conn;  //store connection
      //listen for window closing (compare with main GUI)
      this.addWindowListener(new WindowAdapter()
         {public void windowClosing(WindowEvent e) {dispose();} } );

       //SET UP QUERIES INTO FIRST COMBO BOX
       pQueries = new JComboBox();
       pQueries.setEditable(true);
       
       // add each query to the Combobox
       for (int i = 0; i < DBInfo.params.length; i++) 
       {
          pQueries.addItem(DBInfo.params[i].getTitle());
       }
       pQueries.addActionListener(this);
       
       
       //SET UP SECOND COMBO BOX TO CONTAIN PARAMETER VALUES
       param = new JComboBox();
       param.setEditable(true);
       param.addActionListener(this);
       
       //ADD LABELS AND COMBO BOXES TO PANEL
       JPanel p1 = new JPanel();
       p1.add(new JLabel("Choose a query"));
       p1.add(pQueries);
       paramL = new JLabel("    Choose query first    ");
       p1.add(paramL);
       p1.add(param);
       
       getContentPane().add(p1, BorderLayout.NORTH);
       
       //addTextArea for feedback
       JPanel sPanel = new JPanel();
       feedback = new JTextArea(5,60);
       JScrollPane jsp = new JScrollPane(feedback);
       sPanel.add(jsp);
       getContentPane().add(sPanel, BorderLayout.SOUTH);
       
       //SET UP TABLE IN SCROLLPANE< TO CONTAIN QUERY RESULTS
       quTable = new QueryTable();
       JTable table = new JTable(quTable);
       scrollPane = new JScrollPane(table);
       getContentPane().add(scrollPane, BorderLayout.CENTER);
       scrollPane.setVisible(true);
       
       //set current query to be the first one
       parQuery = DBInfo.getParamAt(0);
       
   }
   
   
   /////////////////////////////////////////////////////////////////
   //Handles all actions from GUI
   //
   //If query title selected
   //	find query object in list of queries
   //	create query of all possible parameter values
   //	execute this query and store the results to the combo box
   //	set correct label for combo box
   //If parameter value selected
   //	execute query for that value
   //	(results are displayed in the table)
   public void actionPerformed(ActionEvent event) {
      //get object source
      Object source = event.getSource();
      /////////////////////////////////////////////////////////////////
      //Query is selected
      if (source == pQueries)
      {
         //find matching query
         parQuery = DBInfo.findQuery((String) pQueries.getSelectedItem());
         
         //create query for this parameterised query
         String query = parQuery.getPossParamsQuery();
         
         //execute SQL query and add column values to combo box
         //there will only be one column in the result set
         try 
         {
            ResultSet resSet;
            PreparedStatement pps = parQuery.getPossPrepStatement();
            resSet = pps.executeQuery();
            
            //adding items to the comboBox fires an action event
            //so disable it
            param.removeActionListener(this);      
            //also hide the table until the parameter has been chosen
            scrollPane.setVisible(false);
            
            //Clear the comboBox, 
            //then for each row, add column to combo box
            if (param.getSelectedItem()!=null)
               param.removeAllItems();
            while (resSet.next()) 
            {
               param.addItem(resSet.getString(1));
            }
            //replace action listener
            param.addActionListener(this); 
            //set instructions for this combo box
            paramL.setText(parQuery.getLabel());
         }
         catch(SQLException e) {
            feedback.setText(e + query);
         }
      }
      
      /////////////////////////////////////////////////////////////////
      //Parameter Value selected
      //Form SQL Query by supplying parameter to prepared statement,
      //executing query and displaying result.
      else if (source == param)
      {
         try 
         {
            String parameter = (String) param.getSelectedItem();
            if (parameter != null) 
            {
               PreparedStatement ps = parQuery.getPrepStatement();
               ps.setString(1,parameter);
               ResultSet rs = ps.executeQuery();
               quTable.formatTable(rs);
               scrollPane.setVisible(true);
            }
         }
         catch (SQLException e) 
         {
            feedback.setText(e + parQuery.getQuery());
         }
      }
   }
}